[![Documentation Status](https://readthedocs.org/projects/peakrdl/badge/?version=latest)](http://peakrdl.readthedocs.io)
[![build](https://github.com/SystemRDL/PeakRDL/workflows/build/badge.svg)](https://github.com/SystemRDL/PeakRDL/actions?query=workflow%3Abuild+branch%3Amain)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/peakrdl.svg)](https://pypi.org/project/peakrdl)

# PeakRDL

PeakRDL is a free and open-source control & status register (CSR) toolchain.
This project provides a command-line tool that unifies many aspects of register
automation centered around the SystemRDL register description language.

## Documentation
See the [PeakRDL Documentation](http://peakrdl.readthedocs.io) for more details.
